@@ -1,12 +1,18 @@
 "print.glmmNPML" <-
 function(x,digits=max(3,getOption('digits')-3), ...){
   np <- length(x$coefficients)
-  m <- seq(1,np)[substr(attr(x$coefficients,'names'),1,4)=='MASS']
-  mass.points <- x$coefficients[m]
-  cat('\nCall: ',deparse(x$call),'\n\n')
-  cat('Coefficients')
-  cat(":\n")
-  print.default(format(x$coefficients[1:np],digits = digits), print.gap = 2,quote = FALSE);cat('\n')
+  if (np > 0){   
+    m <- seq(1,np)[substr(attr(x$coefficients,'names'),1,4)=='MASS']
+    mass.points <- x$coefficients[m]
+    cat('\nCall: ',deparse(x$call),'\n\n')
+    cat('Coefficients')
+    cat(":\n")
+    print.default(format(x$coefficients[1:np],digits = digits), print.gap = 2,quote = FALSE);cat('\n')
+  } else {
+    cat('\nCall: ',deparse(x$call),'\n\n')
+    cat("No coefficients. \n")
+  }
+  
   if (x$family$family=='gaussian' && x$Misc$lambda<=1/length(x$masses)){ #print sigma only if it is constant over components
         cat('MLE of sigma:\t  ',
         format(signif(x$sdev$sdev,digits)),'\n')
@@ -21,7 +27,7 @@ function(x,digits=max(3,getOption('digits')-3), ...){
       cat(":\n")
       print.default(format(p,digits),print.gap=2,quote=FALSE)
    }
-  cat('-2 log L:\t   ', format(round(x$Disparity,digits=1)),"\n")
+  cat('-2 log L:\t   ', format(round(x$disparity,digits=1)),"\n")
   invisible(x)
 }
 
